﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using System.Windows.Input;
using System.Windows.Forms;
using System.Drawing;
using Microsoft.VisualStudio.TestTools.UITesting;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Microsoft.VisualStudio.TestTools.UITest.Extension;
using Keyboard = Microsoft.VisualStudio.TestTools.UITesting.Keyboard;
using System.Diagnostics;


namespace Benday.CodedUi2012.CodedUiTests
{
    /// <summary>
    /// Summary description for CodedUITest1
    /// </summary>
    [CodedUITest]
    public class ListControlCodedUiFixture
    {
        private const string WebSiteUrl = "http://localhost:5012/ListControls";

        public ListControlCodedUiFixture()
        {
        }

        [TestMethod]
        public void BasicWebCodedUiTest()
        {
            BrowserWindow.Launch(new Uri(WebSiteUrl));
            
            this.UIMap.AssertCheckboxIsChecked();
            this.UIMap.AssertDropdownListValueIsUnseletedValue();
            this.UIMap.AssertListBoxHasNoSelectedValues();
            this.UIMap.PopulateValues1();
            this.UIMap.PopulateValues2();
            this.UIMap.ExitTheApp();
        }

        [TestMethod]
        public void BasicWebCodedUiTestWithManipulationOfScreen()
        {
            BrowserWindow.Launch(new Uri(WebSiteUrl));

            ModifyComboBox();
            ModifyCheckbox();
            ModifyListbox();
            
            this.UIMap.ExitTheApp();
        }

        private void ModifyListbox()
        {
            var listboxControl = this.UIMap.UIIndexMyASPNETMVCApplWindow.UIIndexMyASPNETMVCApplDocument1.UIListboxSelectedValueList;

            List<string> previousValues;
            List<string> currentValues;

            previousValues = listboxControl.GetCurrentValues();
            listboxControl.ChangeValue();
            currentValues = listboxControl.GetCurrentValues();
            CollectionAssert.AreNotEqual(previousValues, currentValues, "Selection should have changed.");

            previousValues = listboxControl.GetCurrentValues();
            listboxControl.ChangeValue();
            currentValues = listboxControl.GetCurrentValues();
            CollectionAssert.AreNotEqual(previousValues, currentValues, "Selection should have changed.");

            previousValues = listboxControl.GetCurrentValues();
            listboxControl.ChangeValue();
            currentValues = listboxControl.GetCurrentValues();
            CollectionAssert.AreNotEqual(previousValues, currentValues, "Selection should have changed.");
        }

        private void ModifyCheckbox()
        {
            var checkboxControl = this.UIMap.UIIndexMyASPNETMVCApplWindow.UIIndexMyASPNETMVCApplDocument1.UICheckBoxCheckBox;

            checkboxControl.ChangeValue();
            checkboxControl.ChangeValue();
            checkboxControl.ChangeValue();
            checkboxControl.ChangeValue();
        }

        private void ModifyComboBox()
        {
            var comboboxControl = this.UIMap.UIIndexMyASPNETMVCApplWindow.UIIndexMyASPNETMVCApplDocument1.UIComboboxSelectedValuComboBox;

            string currentValue;
            string previousValue = null;

            comboboxControl.ChangeValue();
            Assert.IsTrue(comboboxControl.IsAnythingSelected(), "Something should be selected."); 
            currentValue = comboboxControl.GetCurrentValue();
            Assert.AreNotEqual<string>(previousValue, currentValue, "Value should have changed.");
            previousValue = currentValue;

            comboboxControl.ChangeValue();
            Assert.IsTrue(comboboxControl.IsAnythingSelected(), "Something should be selected.");
            currentValue = comboboxControl.GetCurrentValue();
            Assert.AreNotEqual<string>(previousValue, currentValue, "Value should have changed.");
            previousValue = currentValue;

            comboboxControl.ChangeValue();
            Assert.IsTrue(comboboxControl.IsAnythingSelected(), "Something should be selected.");
            currentValue = comboboxControl.GetCurrentValue();
            Assert.AreNotEqual<string>(previousValue, currentValue, "Value should have changed.");
            previousValue = currentValue;

            comboboxControl.ChangeValue();
            Assert.IsTrue(comboboxControl.IsAnythingSelected(), "Something should be selected.");
            currentValue = comboboxControl.GetCurrentValue();
            Assert.AreNotEqual<string>(previousValue, currentValue, "Value should have changed.");
            previousValue = currentValue;
        }

        #region Additional test attributes

        // You can use the following additional attributes as you write your tests:

        ////Use TestInitialize to run code before running each test 
        //[TestInitialize()]
        //public void MyTestInitialize()
        //{        
        //    // To generate code for this test, select "Generate Code for Coded UI Test" from the shortcut menu and select one of the menu items.
        //    // For more information on generated code, see http://go.microsoft.com/fwlink/?LinkId=179463
        //}

        ////Use TestCleanup to run code after each test has run
        //[TestCleanup()]
        //public void MyTestCleanup()
        //{        
        //    // To generate code for this test, select "Generate Code for Coded UI Test" from the shortcut menu and select one of the menu items.
        //    // For more information on generated code, see http://go.microsoft.com/fwlink/?LinkId=179463
        //}

        #endregion

        /// <summary>
        ///Gets or sets the test context which provides
        ///information about and functionality for the current test run.
        ///</summary>
        public TestContext TestContext
        {
            get
            {
                return testContextInstance;
            }
            set
            {
                testContextInstance = value;
            }
        }
        private TestContext testContextInstance;

        public UIMap UIMap
        {
            get
            {
                if ((this.map == null))
                {
                    this.map = new UIMap();
                }

                return this.map;
            }
        }

        private UIMap map;
    }
}
